@@ -1,6 +1,6 @@
 package Pithub::Repos;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01036';
+our $VERSION = '0.01037';
 # ABSTRACT: Github v3 Repos API
 
 use Moo;
@@ -50,6 +50,31 @@ sub branches {
 }
 
 
+sub rename_branch {
+    my ( $self, %args ) = @_;
+    croak 'Missing parameters: branch' unless $args{branch};
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    $self->_validate_user_repo_args( \%args );
+    return $self->request(
+        method => 'POST',
+        path   => sprintf( '/repos/%s/%s/branches/%s/rename', delete $args{user}, delete $args{repo}, delete $args{branch} ),
+        %args,
+    );
+}
+
+
+sub merge_branch {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    $self->_validate_user_repo_args( \%args );
+    return $self->request(
+        method => 'POST',
+        path   => sprintf( '/repos/%s/%s/merges', delete $args{user}, delete $args{repo} ),
+        %args,
+    );
+}
+
+
 sub collaborators {
     return shift->_create_instance('Pithub::Repos::Collaborators', @_);
 }
@@ -265,7 +290,7 @@ Pithub::Repos - Github v3 Repos API
 
 =head1 VERSION
 
-version 0.01036
+version 0.01037
 
 =head1 METHODS
 
@@ -304,6 +329,49 @@ See also L<branch> to get information about a single branch.
 
 =back
 
+=head2 rename_branch
+
+=over
+
+=item *
+
+Rename a branch
+
+    POST /repos/:user/:repo/branches/:branch/rename
+
+Examples:
+
+    my $b = Pithub::Repos->new;
+    my $result = $b->rename_branch(
+        user => 'plu',
+        repo => 'Pithub',
+        branch  => 'travis',
+        data => { new_name => 'travis-ci' }
+    );
+
+=back
+
+=head2 merge_branch
+
+=over
+
+=item *
+
+Merge a branch
+
+    POST /repos/:user/:repo/merges
+
+Examples:
+
+    my $b = Pithub::Repos->new;
+    my $result = $b->rename_branch(
+        user => 'plu',
+        repo => 'Pithub',
+        data => { base => 'master', head => 'travis', message => 'My commit message' }
+    );
+
+=back
+
 =head2 collaborators
 
 Provides access to L<Pithub::Repos::Collaborators>.
@@ -554,7 +622,7 @@ Johannes Plunien <plu@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2019 by Johannes Plunien.
+This software is copyright (c) 2011 by Johannes Plunien.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
